@@ -1895,9 +1895,9 @@ void CalendarView::processIncidenceSelection(const Akonadi::Item &item, const QD
     bool subtodo = false;
 
     const bool organizerEvents
-        = CalendarSupport::KCalPrefs::instance()->thatIsMe(incidence->organizer()->email());
-    const bool groupEvents = incidence->attendeeByMails(
-        CalendarSupport::KCalPrefs::instance()->allEmails());
+        = CalendarSupport::KCalPrefs::instance()->thatIsMe(incidence->organizer().email());
+    const bool groupEvents = !incidence->attendeeByMails(
+        CalendarSupport::KCalPrefs::instance()->allEmails()).isNull();
 
     if (incidence->type() == KCalCore::Incidence::TypeTodo) {
         todo = true;
@@ -1992,10 +1992,8 @@ void CalendarView::takeOverEvent()
         return;
     }
 
-    incidence->setOrganizer(
-        KCalCore::Person::Ptr(new KCalCore::Person(
-                                  CalendarSupport::KCalPrefs::instance()->fullName(),
-                                  CalendarSupport::KCalPrefs::instance()->email())));
+    incidence->setOrganizer(KCalCore::Person(CalendarSupport::KCalPrefs::instance()->fullName(),
+                                             CalendarSupport::KCalPrefs::instance()->email()));
     incidence->recreate();
     incidence->setReadOnly(false);
 
@@ -2238,7 +2236,7 @@ void CalendarView::deleteSubTodosIncidence(const Akonadi::Item &todoItem)
         return;
     }
     const Akonadi::Item::List subTodos = mCalendar->childItems(todoItem.id());
-    foreach (const Akonadi::Item &item, subTodos) {
+    for (const Akonadi::Item &item : subTodos) {
         if (CalendarSupport::hasTodo(item)) {
             deleteSubTodosIncidence(item);
         }
