@@ -108,8 +108,8 @@ FilterEdit::FilterEdit(QList<KCalCore::CalFilter *> *filters, QWidget *parent)
         i18nc("@info:whatsthis",
               "Press this button to remove the currently active filter."));
 
-    connect(mRulesList, QOverload<>::of(&QListWidget::itemSelectionChanged),
-            this, QOverload<>::of(&FilterEdit::filterSelected));
+    connect(mRulesList, qOverload<>(&QListWidget::itemSelectionChanged),
+            this, qOverload<>(&FilterEdit::filterSelected));
 
     connect(mNewButton, &QPushButton::clicked, this, &FilterEdit::bNewPressed);
     connect(mDeleteButton, &QPushButton::clicked, this, &FilterEdit::bDeletePressed);
@@ -298,7 +298,7 @@ void FilterEdit::updateSelectedName(const QString &newText)
     }
     bool allOk = true;
 
-    foreach (KCalCore::CalFilter *i, *mFilters) {
+    for (KCalCore::CalFilter *i : qAsConst(*mFilters)) {
         if (i && i->name().isEmpty()) {
             allOk = false;
         }
