@@ -44,7 +44,6 @@
 #include <QToolTip>
 #include <QMimeData>
 #include <KLocalizedString>
-#include <QLocale>
 
 // ============================================================================
 //  K O D A Y M A T R I X
@@ -243,7 +242,7 @@ void KODayMatrix::updateView(const QDate &actdate)
                 holiStr = holidays.join(i18nc("delimiter for joining holiday names", ","));
             }
             if (holiStr.isEmpty()) {
-                holiStr = QStringLiteral("");
+                holiStr = QLatin1String("");
             }
         }
         mHolidays[i] = holiStr;
@@ -372,7 +371,7 @@ void KODayMatrix::updateEvents()
               && !KOPrefs::instance()->mDailyRecur)
             && !(recurType == KCalCore::Recurrence::rWeekly
                  && !KOPrefs::instance()->mWeeklyRecur)) {
-            KCalCore::SortableList<QDateTime> timeDateList;
+            KCalCore::DateTimeList timeDateList;
             const bool isRecurrent = event->recurs();
             const int eventDuration = dtStart.daysTo(dtEnd);
 
