@@ -182,7 +182,7 @@ void TodoSummaryWidget::updateView()
 
         QString str;
 
-        Q_FOREACH (const KCalCore::Todo::Ptr &todo, prList) {
+        for (const KCalCore::Todo::Ptr &todo : qAsConst(prList)) {
             bool makeBold = false;
             int daysTo = -1;
 
@@ -309,14 +309,14 @@ void TodoSummaryWidget::updateView()
         mLabels.append(noTodos);
     }
 
-    Q_FOREACH (label, mLabels) {   //krazy:exclude=foreach as label is a pointer
+    for (QLabel *label : qAsConst(mLabels)) {
         label->show();
     }
 }
 
 void TodoSummaryWidget::viewTodo(const QString &uid)
 {
-    Akonadi::Item::Id id = mCalendar->item(uid).id();
+    const Akonadi::Item::Id id = mCalendar->item(uid).id();
 
     if (id != -1) {
         mPlugin->core()->selectPlugin(QStringLiteral("kontact_todoplugin"));  //ensure loaded
