@@ -234,7 +234,8 @@ void SDSummaryWidget::slotBirthdayJobFinished(KJob *job)
     // ;)
     BirthdaySearchJob *bJob = qobject_cast<BirthdaySearchJob *>(job);
     if (bJob) {
-        foreach (const Akonadi::Item &item, bJob->items()) {
+        const auto items = bJob->items();
+        for (const Akonadi::Item &item : items) {
             if (item.hasPayload<KContacts::Addressee>()) {
                 const KContacts::Addressee addressee = item.payload<KContacts::Addressee>();
                 const QDate birthday = addressee.birthday().date();
@@ -269,7 +270,7 @@ void SDSummaryWidget::createLabels()
     // Remove all special date labels from the layout and delete them, as we
     // will re-create all labels below.
     setUpdatesEnabled(false);
-    foreach (label, mLabels) {
+    for (QLabel *label : qAsConst(mLabels)) {
         mLayout->removeWidget(label);
         delete(label);
         update();
@@ -561,9 +562,9 @@ void SDSummaryWidget::createLabels()
                 mLayout->addWidget(urlLabel, counter, 4);
                 mLabels.append(urlLabel);
 
-                connect(urlLabel, QOverload<const QString &>::of(&KUrlLabel::leftClickedUrl),
+                connect(urlLabel, qOverload<const QString &>(&KUrlLabel::leftClickedUrl),
                         this, &SDSummaryWidget::mailContact);
-                connect(urlLabel, QOverload<const QString &>::of(&KUrlLabel::rightClickedUrl),
+                connect(urlLabel, qOverload<const QString &>(&KUrlLabel::rightClickedUrl),
                         this, &SDSummaryWidget::popupMenu);
             } else {
                 label = new QLabel(this);
