@@ -289,9 +289,10 @@ public:
             mHolidayCheckCombo->addItem(i.key(), i.value());
         }
 
-        QString regionStr = KHolidays::HolidayRegion::defaultRegionCode();
-        foreach (KHolidays::HolidayRegion *region, KOGlobals::self()->holidays()) {
-            QString regionStr = region->regionCode();
+        //QString regionStr = KHolidays::HolidayRegion::defaultRegionCode();
+        const auto holidays = KOGlobals::self()->holidays();
+        for (KHolidays::HolidayRegion *region : holidays) {
+            const QString regionStr = region->regionCode();
             mHolidayCheckCombo->setItemCheckState(
                 mHolidayCheckCombo->findData(regionStr), Qt::Checked);
         }
@@ -407,7 +408,7 @@ public:
             CalendarSupport::KCalPrefs::instance()->reminderTimeItem()->whatsThis());
         mReminderTimeSpin->setToolTip(
             CalendarSupport::KCalPrefs::instance()->reminderTimeItem()->toolTip());
-        connect(mReminderTimeSpin, QOverload<int>::of(&QSpinBox::valueChanged),
+        connect(mReminderTimeSpin, qOverload<int>(&QSpinBox::valueChanged),
                 this, &KOPrefsDialogMain::slotWidChanged);
         remindersLayout->addWidget(mReminderTimeSpin, 0, 1);
 
@@ -416,7 +417,7 @@ public:
             CalendarSupport::KCalPrefs::instance()->reminderTimeUnitsItem()->toolTip());
         mReminderUnitsCombo->setWhatsThis(
             CalendarSupport::KCalPrefs::instance()->reminderTimeUnitsItem()->whatsThis());
-        connect(mReminderUnitsCombo, QOverload<int>::of(&KComboBox::activated),
+        connect(mReminderUnitsCombo, qOverload<int>(&KComboBox::activated),
                 this, &KOPrefsDialogMain::slotWidChanged);
         mReminderUnitsCombo->addItem(
             i18nc("@item:inlistbox reminder units in minutes", "minute(s)"));
@@ -474,7 +475,8 @@ protected:
     void usrWriteConfig() override
     {
         QStringList HolidayRegions;
-        foreach (const QString &str, mHolidayCheckCombo->checkedItems()) {
+        const auto checkedItems = mHolidayCheckCombo->checkedItems();
+        for (const QString &str : checkedItems) {
             int index = mHolidayCheckCombo->findText(str);
             if (index >= 0) {
                 HolidayRegions.append(mHolidayCheckCombo->itemData(index).toString());
@@ -837,7 +839,7 @@ KOPrefsDialogColorsAndFonts::KOPrefsDialogColorsAndFonts(QWidget *parent)
               "Select here the event category you want to modify. "
               "You can change the selected category color using "
               "the button below."));
-    connect(mCategoryCombo, QOverload<int>::of(&KComboBox::activated),
+    connect(mCategoryCombo, qOverload<int>(&KComboBox::activated),
             this, &KOPrefsDialogColorsAndFonts::updateCategoryColor);
     categoryLayout->addWidget(mCategoryCombo, 1, 0);
 
@@ -872,7 +874,7 @@ KOPrefsDialogColorsAndFonts::KOPrefsDialogColorsAndFonts(QWidget *parent)
               "Select the calendar you want to modify. "
               "You can change the selected calendar color using "
               "the button below."));
-    connect(mResourceCombo, QOverload<int>::of(&Akonadi::CollectionComboBox::activated),
+    connect(mResourceCombo, qOverload<int>(&Akonadi::CollectionComboBox::activated),
             this, &KOPrefsDialogColorsAndFonts::updateResourceColor);
     resourceLayout->addWidget(mResourceCombo);
 
@@ -1104,7 +1106,7 @@ KOPrefsDialogGroupwareScheduling::KOPrefsDialogGroupwareScheduling(QWidget *pare
 
     // signals and slots connections
 
-    connect(mGroupwarePage->publishDays, QOverload<int>::of(&QSpinBox::valueChanged),
+    connect(mGroupwarePage->publishDays, qOverload<int>(&QSpinBox::valueChanged),
             this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
     connect(mGroupwarePage->publishUrl, &QLineEdit::textChanged,
             this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
@@ -1124,7 +1126,7 @@ KOPrefsDialogGroupwareScheduling::KOPrefsDialogGroupwareScheduling(QWidget *pare
             this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
     connect(mGroupwarePage->retrieveUrl, &QLineEdit::textChanged,
             this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
-    connect(mGroupwarePage->publishDelay, QOverload<int>::of(&QSpinBox::valueChanged),
+    connect(mGroupwarePage->publishDelay, qOverload<int>(&QSpinBox::valueChanged),
             this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
     connect(mGroupwarePage->fullDomainRetrieval, &QCheckBox::toggled,
             this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
